@@ -10,7 +10,7 @@
 ###############################################################################
 
 import re
-from collections import OrderedDict
+from collections import OrderedDict, defaultdict
 from os.path import isfile, join, relpath
 
 import jinja2
@@ -75,12 +75,14 @@ CHECK_TYPE_SCHEMAS = {
     "range": {
         "expression": Str(),  # TODO: replace this with a regex
         "limits": Map({"min": Float(), "max": Float()}),
-        "abs_tolerance": Float(),
         Optional("blind_ranges"): Map({"min": Float(), "max": Float()})
         | Seq(Map({"min": Float(), "max": Float()})),
+        Optional("exp_mean"): Float(),
+        Optional("exp_std"): Float(),
+        Optional("mean_tolerance"): Float(),
+        Optional("std_tolerance"): Float(),
     },
     "range_nd": {
-        "num_dimensions": Int(),
         "expressions": Map(
             {  # TODO: replace Str() with a regex
                 "x": Str(),
@@ -97,7 +99,6 @@ CHECK_TYPE_SCHEMAS = {
                 Optional("w"): Map({"min": Float(), "max": Float()}),
             }
         ),
-        "abs_tolerance": Float(),
         Optional("blind_ranges"): Seq(
             Map(
                 {
@@ -115,9 +116,29 @@ CHECK_TYPE_SCHEMAS = {
     "num_entries_per_invpb": {
         "count_per_invpb": Float(),
     },
+    "range_bkg_subtracted": {
+        "expression": Str(),
+        "limits": Map({"min": Float(), "max": Float()}),
+        "expr_for_subtraction": Str(),
+        "mean_sig": Float(),
+        "background_shift": Float(),
+        "background_window": Float(),
+        "signal_window": Float(),
+        Optional("blind_ranges"): Map({"min": Float(), "max": Float()})
+        | Seq(Map({"min": Float(), "max": Float()})),
+    },
 }
 BASE_CHECK_SCHEMA = {
     "type": Enum(list(CHECK_TYPE_SCHEMAS)),
+    "tree_pattern": Str(),
+}
+BASE_CHECK_DEFAULT_VALUES = {
+    "tree_pattern": r"(.*/DecayTree)|(.*/MCDecayTree)",
+    "blind_ranges": [],
+    "exp_mean": 0.0,
+    "exp_std": 0.0,
+    "mean_tolerance": 0.0,
+    "std_tolerance": 0.0,
 }
 
 
@@ -139,7 +160,7 @@ def render_yaml(raw_yaml):
         raise ValueError(
             "Failed to render with jinja2 on line %s: %s"
             % (getattr(e, "lineno", "unknown"), e)
-        )
+        ) from e
     return rendered_yaml
 
 
@@ -232,6 +253,14 @@ def parse_yaml(rendered_yaml):
                 **BASE_CHECK_SCHEMA,
                 **CHECK_TYPE_SCHEMAS[str(check_data["type"])],
             }
+            # apply default values
+            for key, value in BASE_CHECK_SCHEMA.items():
+                if key not in check_data and key in BASE_CHECK_DEFAULT_VALUES:
+                    check_schema.pop(key, None)
+                    check_schema[
+                        Optional(key, default=BASE_CHECK_DEFAULT_VALUES[key])
+                    ] = value
+
             check_data.revalidate(Map(check_schema))
         # if checks pass validation, store elsewhere & delete from main data
         # so that normal jobs aren't impacted
@@ -334,18 +363,98 @@ def _normalise_filetype(prod_name, job_name, filetype):
     return filetype
 
 
+def _check_name_magnet_polarity(bk_query, job_name):
+    match = re.search(r"-mag(up|down)[-/]", bk_query)
+    if not match:
+        return [f"Failed to find magnet polarity in {bk_query}"]
+    good_pol = match.groups()[0]
+    bad_pol = {"down": "up", "up": "down"}[good_pol]
+    if f"mag{bad_pol}" in job_name:
+        raise ValueError(
+            f"Found 'mag{bad_pol}' in job name {job_name!r} with"
+            f"'mag{good_pol}' input ({bk_query!r}). "
+            "Has the wrong magnet polarity been used?"
+        )
+    match = re.search(r"([^a-z0-9]|\b)m(u|d)([^a-z0-9]|\b)", job_name)
+    if match and match.groups()[1] == bad_pol[0]:
+        raise ValueError(
+            f"Found 'm{bad_pol[0]}' in job name {job_name!r} with"
+            f"'mag{good_pol}' input ({bk_query!r}). "
+            "Has the wrong magnet polarity been used?"
+        )
+    return []
+
+
 def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
+
+    bk_query_to_job = defaultdict(set)
+
+    warnings = []
+
     # Ensure all values that can be either a list or a string are lists of strings
     for job_name, job_data in jobs_data.items():
         try:
             _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data)
         except Exception as e:
-            raise ValueError(f"Failed to validate {job_name!r} with error {e!r}")
+            raise ValueError(f"Failed to validate {job_name!r} with error {e!r}") from e
+        if "bk_query" in job_data["input"]:
+            if job_data["input"]["bk_query"].lower() in bk_query_to_job:
+                warnings.append(
+                    f'Duplicate bk_query found (this is a case insensitive check): {job_data["input"]["bk_query"].lower()}'
+                )
+            bk_query_to_job[job_data["input"]["bk_query"].lower()].add(job_name.lower())
+
+    for query, job_set in bk_query_to_job.items():
+        for job_name in job_set:
+            warnings.extend(_check_name_magnet_polarity(query, job_name))
+
+    polarity_len_swap = {"magdown": 5, "magup": 7}
+    polarity_swap = {"magdown": "magup", "magup": "magdown"}
+
+    # check that both polarities are always used for a given bk_query
+    for query in bk_query_to_job:
+        index = None
+        query_polarity = None
+        both_polarities = False
+        for polarity in {"magdown", "magup"}:
+            if polarity in query:
+                index = query.find(polarity)
+                query_polarity = polarity
+        if query_polarity:
+            for compare_query in bk_query_to_job:
+                if compare_query != query:
+                    if polarity_swap[query_polarity] in compare_query:
+                        if (
+                            compare_query[:index]
+                            + query_polarity
+                            + compare_query[
+                                (index + polarity_len_swap[query_polarity]) :
+                            ]
+                            == query
+                        ):
+                            both_polarities = True
+                            if len(bk_query_to_job[query]) != len(
+                                bk_query_to_job[compare_query]
+                            ):
+                                warnings.append(
+                                    f"The number of jobs requesting {query} does not"
+                                    " match the number of jobs requesting its opposite"
+                                    f" polarity counterpart {compare_query}."
+                                )
+            if not both_polarities:
+                warnings.append(
+                    f"{query} has been requested as input for {len(bk_query_to_job[query])} job(s)"
+                    " but its opposite polarity counterpart has not been requested for any jobs."
+                    " Are you sure you do not want the other polarity?"
+                )
+
     # Validate checks
     try:
         _validate_checks_data(checks_data, jobs_data)
     except Exception as e:
-        raise ValueError(f"Failed to validate checks with error {e!r}")
+        raise ValueError(f"Failed to validate checks with error {e!r}") from e
+
+    return warnings
 
 
 def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
