@@ -567,7 +567,6 @@ def test_good_with_checks_no_defaults():
             limits:
                 min: 1750
                 max: 2000
-            abs_tolerance: 1
             blind_ranges:
                 -
                     min: 1850
@@ -577,7 +576,6 @@ def test_good_with_checks_no_defaults():
                     max: 1910
         check_range_nd:
             type: range_nd
-            num_dimensions: 3
             expressions:
                 x: Tuple D0_M
                 y: Tuple Dst_M-D0_M
@@ -592,7 +590,6 @@ def test_good_with_checks_no_defaults():
                 z:
                     min: 3
                     max: 7
-            abs_tolerance: 1
             blind_ranges:
                 -
                     x:
@@ -651,14 +648,12 @@ def test_good_with_checks_no_defaults():
     assert checks_data["check_range"]["expression"] == "Tuple D0_M"
     assert checks_data["check_range"]["limits"]["min"] == 1750.0
     assert checks_data["check_range"]["limits"]["max"] == 2000.0
-    assert checks_data["check_range"]["abs_tolerance"] == 1.0
     assert checks_data["check_range"]["blind_ranges"] == [
         {"min": 1850.0, "max": 1880.0},
         {"min": 1900.0, "max": 1910.0},
     ]
 
     assert checks_data["check_range_nd"]["type"] == "range_nd"
-    assert checks_data["check_range_nd"]["num_dimensions"] == 3
     assert checks_data["check_range_nd"]["expressions"] == {
         "x": "Tuple D0_M",
         "y": "Tuple Dst_M-D0_M",
@@ -670,7 +665,6 @@ def test_good_with_checks_no_defaults():
     }
     assert checks_data["check_range_nd"]["limits"]["y"] == {"min": 139.0, "max": 150.0}
     assert checks_data["check_range_nd"]["limits"]["z"] == {"min": 3.0, "max": 7.0}
-    assert checks_data["check_range_nd"]["abs_tolerance"] == 1.0
     assert checks_data["check_range_nd"]["blind_ranges"] == [
         {
             "x": {"min": 1850.0, "max": 1880.0},
@@ -703,7 +697,6 @@ def test_good_with_checks_defaults_extra_checks():
             limits:
                 min: 1750
                 max: 2000
-            abs_tolerance: 1
             blind_ranges:
                 -
                     min: 1850
@@ -766,7 +759,6 @@ def test_good_with_checks_defaults_extra_checks():
     assert checks_data["check_range"]["expression"] == "Tuple D0_M"
     assert checks_data["check_range"]["limits"]["min"] == 1750.0
     assert checks_data["check_range"]["limits"]["max"] == 2000.0
-    assert checks_data["check_range"]["abs_tolerance"] == 1.0
     assert checks_data["check_range"]["blind_ranges"] == [
         {"min": 1850.0, "max": 1880.0},
         {"min": 1900.0, "max": 1910.0},
@@ -950,3 +942,196 @@ def test_filetype_validation():
 
     assert _normalise_filetype("PROD", "JOB", "XICPS_MC.ROOT") == "XICPS_MC.ROOT"
     assert _normalise_filetype("PROD", "JOB", "xicps_mc.root") == "XICPS_MC.ROOT"
+
+
+def test_wrong_polarity():
+    rendered_yaml = dedent(
+        """\
+    job_MagDown:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MagUp:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2017/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    with pytest.raises(ValueError):
+        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+
+
+def test_wrong_polarity_acronym():
+    rendered_yaml = dedent(
+        """\
+    job_MD:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MU:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2017/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    with pytest.raises(ValueError):
+        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+
+
+def test_tuple_in_job_name():
+    rendered_yaml = dedent(
+        """\
+    job_MagDown_tuple:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MagUp_tuple:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert warnings == []
+
+
+def test_polarity_acronym():
+    rendered_yaml = dedent(
+        """\
+    job_MagDown_2018:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MagUp_2018:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MD_2017:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2017/Beam6500GeV-2017-MagDown/Sim09g/Trig0x62661709/Reco17/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_MU_2017:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2017/Beam6500GeV-2017-MagUp/Sim09g/Trig0x62661709/Reco17/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert warnings == []
+
+
+def test_missing_polarity():
+    rendered_yaml = dedent(
+        """\
+    job_MagDown:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert (
+        "/mc/2018/beam6500gev-2018-magdown/sim09g/trig0x617d18a4/reco18/24142001/allstreams.dst"
+        " has been requested as input for 1 job(s)"
+        " but its opposite polarity counterpart has not been requested for any jobs."
+        " Are you sure you do not want the other polarity?" in warnings
+    )
+
+
+def test_duplicate_bk_query():
+    rendered_yaml = dedent(
+        """\
+    job_1:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_2:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/b.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert (
+        "Duplicate bk_query found (this is a case insensitive check): "
+        "/mc/2018/beam6500gev-2018-magdown/sim09g/trig0x617d18a4/reco18/24142001/allstreams.dst"
+        in warnings
+    )
